@@ -1,12 +1,10 @@
 package Foo::Parent;
-our $VERSION = '0.0100';
-
-
+our $VERSION = '1.0101';
 
 use Moose;
-extends 'SimpleDB::Class::Domain';
+extends 'SimpleDB::Class::Item';
 
-__PACKAGE__->set_name('foo_parent');
+__PACKAGE__->set_domain_name('foo_parent');
 __PACKAGE__->add_attributes(title=>{isa=>'Str'});
 __PACKAGE__->has_many('domains', 'Foo::Domain', 'parentId');
 
